@@ -2,15 +2,9 @@ use strict;
 use warnings;
 
 package Test::Deep::Any;
-use Carp qw( confess );
 
 use Test::Deep::Cmp;
 
-use vars qw( @ISA );
-@ISA = qw( Test::Deep::Cmp );
-
-use Data::Dumper qw(Dumper);
-
 use overload
 	'&' => \&add,
 ;
@@ -27,35 +21,14 @@ sub init
 sub descend
 {
 	my $self = shift;
-	my $d1 = shift;
-
-	my %data = (type => $self, vals => [$d1, $self->{val}]);
-
-	$Test::Deep::Stack->push(\%data);
-
-	my $ok = 0;
+	my $got = shift;
 
 	foreach my $cmp (@{$self->{val}})
 	{
-		if (Test::Deep::eq_deeply_cache($d1, $cmp))
-		{
-			$ok = 1;
-			last;
-		}
+		return 1 if Test::Deep::eq_deeply_cache($got, $cmp);
 	}
 
-	$Test::Deep::Stack->pop if $ok;
-
-	return $ok;
-}
-
-sub compare
-{
-	my $self = shift;
-
-	my $other = shift;
-
-	return Test::Deep::descend($self->{val}, $other->{val});
+	return 0;
 }
 
 sub diagnostics
@@ -63,11 +36,10 @@ sub diagnostics
 	my $self = shift;
 	my ($where, $last) = @_;
 
-	my $vals = $last->{vals};
-	my ($got, $expect) = @$vals;
+	my $expect = $self->{val};
 
-	$got = $self->renderGot($got);
-	my $things = join(", ", map {$_->renderExp($_)} @$expect);
+	my $got = $self->renderGot($last->{got});
+	my $things = join(", ", map {$_->renderExp} @$expect);
 
 	my $diag = <<EOM;
 Comparing $where with Any
